@@ -13,25 +13,25 @@
 #ifndef STATIONDATABASE_H
 #define STATIONDATABASE_H
 
-#include <qobject.h>
+#include <qmap.h>
+#include <qstring.h>
+
+#include <klocale.h>
+#include <kstandarddirs.h>
+
 /**
-This is the main database for mapping METAR codes to Station names.
+This is the main database for mapping METAR codes to Station information.
 
 @author ian reinhart geiser
 */
 
 class StationInfo;
 
-class StationDatabase : public QObject
+class StationDatabase
 {
-	Q_OBJECT
 public:
-    StationDatabase(QObject *parent = 0L, const char *name =0L);
-
-    virtual ~StationDatabase();
-
-
-    bool loadDatabase();
+    StationDatabase(const QString path = locate("data", "kweatherservice/stations.dat"));
+    ~StationDatabase();
 
     QString stationNameFromID(const QString& id);
 
@@ -46,6 +46,7 @@ private:
 
     bool loadStation( const QString & stationID );
 
+    const QString mPath;
 };
 
 #endif
